cheesecake.logger.Producer

Package cheesecake :: Module logger :: Class Producer |
[hide private]
[frames] | no frames]

## Class Producer
source code

    object --+
             |
            Producer

Known Subclasses:
  MultipleProducer

Log producer API which sends messages to be logged to a 'consumer' object, which then prints them to stdout, stderr, files, etc.

Nested Classes | [hide private]
Message |

Instance Methods | [hide private]
| __init__(self, keywords) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| __repr__(self) repr(x)
| __getattr__(self, name)
| __call__(self, *args)
| _getconsumer(self, keywords)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Variables | [hide private]
keywords2consumer |
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, keywords) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### __getattr__(self, name) (Qualification operator) | source code

### __call__(self, *args) (Call operator) | source code

### _getconsumer(self, keywords) | source code

Class Variable Details | [hide private]

    ### keywords2consumer Value:
        {'default': <function default_consumer at 0xb7aa8dbc>}